Crossbar.io FX Database
=======================

| |Version| |Build| |Deploy| |Docs|

**cfxdb** is a CrossbarFX Python support package with core database access classes
written in native Python. The package allows direct in-memory data access from
Python programs (including Jupyter notebooks) to CrossbarFX edge node data:

* persisted WAMP event history
* persisted router tracing data
* XBR market maker transactions database
* XBR network backend database
* WAMP session cache
* custom user, embedded object databases

--------------

*Copyright (C) Crossbar.io Technologies GmbH. All rights reserved.
WAMP, Crossbar.io and XBR are trademarks of Crossbar.io Technologies GmbH.*

.. |Version| image:: https://img.shields.io/pypi/v/cfxdb.svg
   :target: https://pypi.python.org/pypi/cfxdb
   :alt: Version

.. |Build| image:: https://github.com/crossbario/cfxdb/workflows/main/badge.svg
   :target: https://github.com/crossbario/cfxdb/actions?query=workflow%3Amain
   :alt: Build

.. |Deploy| image:: https://github.com/crossbario/cfxdb/workflows/deploy/badge.svg
   :target: https://github.com/crossbario/cfxdb/actions?query=workflow%3Adeploy
   :alt: Deploy

.. |Docs| image:: https://img.shields.io/badge/docs-brightgreen.svg?style=flat
   :target: https://crossbario.com/docs/cfxdb/index.html
   :alt: Docs
